diff libpurple/protocols/qq/char_conv.h @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 48f3837a9625
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/qq/char_conv.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/qq/char_conv.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file char_conv.h
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -31,13 +31,13 @@
 
 gint convert_as_pascal_string(guint8 *data, gchar **ret, const gchar *from_charset);
 
-gchar *qq_smiley_to_gaim(gchar *text);
+gchar *qq_smiley_to_purple(gchar *text);
 
-gchar *gaim_smiley_to_qq(gchar *text);
+gchar *purple_smiley_to_qq(gchar *text);
 
 gchar *utf8_to_qq(const gchar *str, const gchar *to_charset);
 gchar *qq_to_utf8(const gchar *str, const gchar *from_charset);
-gchar *qq_encode_to_gaim(guint8 *font_attr_data, gint len, const gchar *msg);
+gchar *qq_encode_to_purple(guint8 *font_attr_data, gint len, const gchar *msg);
 
 gchar *qq_im_filter_html(const gchar *text);
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.